@@ -16,6 +16,8 @@ use Test::Mock::Redis;
 use Data::Chronicle::Reader;
 use Data::Chronicle::Writer;
 
+our $VERSION = '0.11';    ## VERSION
+
 =head3 C<< my $ch = get_mocked_chronicle(); >>
 
 Creates a simulated chronicle connected to a temporary storage.
@@ -26,7 +28,7 @@ sub get_mocked_chronicle {
     my $redis = Test::Mock::Redis->new(server => 'whatever');
 
     my $pgsql = Test::PostgreSQL->new();
-    my $dbh = DBI->connect($pgsql->dsn);
+    my $dbh   = DBI->connect($pgsql->dsn);
 
     my $stmt = qq(CREATE TABLE chronicle (
       id bigserial,
@@ -39,33 +41,32 @@ sub get_mocked_chronicle {
     ););
 
     {
-        local $SIG{__WARN__} = sub {};
+        local $SIG{__WARN__} = sub { };
         $dbh->do($stmt);
     }
 
     my $chronicle_r = Data::Chronicle::Reader->new(
-        cache_reader    => $redis,
-        db_handle       => $dbh);
+        cache_reader => $redis,
+        db_handle    => $dbh
+    );
 
     my $chronicle_w = Data::Chronicle::Writer->new(
-        cache_writer    => $redis,
-        db_handle       => $dbh,
-        ttl             => 86400);
-
+        cache_writer => $redis,
+        db_handle    => $dbh,
+        ttl          => 86400
+    );
 
     #we need to store a reference to $pgsql or else, as soon as this method
     #is returned, it will be destroyed and connection will be lost.
     $chronicle_r->meta->add_attribute(
         dummy => (
             accessor => 'dummy',
-        )
-    );
+        ));
 
     $chronicle_w->meta->add_attribute(
         dummy => (
             accessor => 'dummy',
-        )
-    );
+        ));
 
     $chronicle_r->dummy($pgsql);
     $chronicle_w->dummy($pgsql);
