@@ -11,7 +11,7 @@ Data::Chronicle::Writer - Provides writing to an efficient data storage for vola
 
 =cut
 
-our $VERSION = $Data::Chronicle::VERSION;
+our $VERSION = '0.11';    ## VERSION
 
 =head1 DESCRIPTION
 
@@ -30,7 +30,7 @@ The module uses Redis cache to provide efficient data storage and retrieval.
 
 =item B<Persistent>
 
-In addition to caching every incoming data, it is also stored in PostgresSQL for future retrieval.
+In addition to caching every incoming data, it is also stored in PostgreSQL for future retrieval.
 
 =item B<Transparent>
 
@@ -43,17 +43,17 @@ to save data and another method to retrieve it. All the underlying complexities
 
  my $d = get_some_log_data();
 
- my $chronicle_w = Data::Chronicle::Writer->new( 
+ my $chronicle_w = Data::Chronicle::Writer->new(
     cache_writer => $writer,
     db_handle    => $dbh,
     ttl          => 86400);
 
- my $chronicle_r = Data::Chronicle::Reader->new( 
+ my $chronicle_r = Data::Chronicle::Reader->new(
     cache_reader => $reader,
     db_handle    => $dbh);
 
 
- #store data into Chronicle - each time we call `set` it will also store 
+ #store data into Chronicle - each time we call `set` it will also store
  #a copy of the data for historical data retrieval
  $chronicle_w->set("log_files", "syslog", $d);
 
@@ -87,9 +87,9 @@ This represents the seconds until expiry, and default is C<undef>, meaning that
 =cut
 
 has 'ttl' => (
-    isa      => 'Maybe[Int]',
-    is       => 'ro',
-    default  => undef,
+    isa     => 'Maybe[Int]',
+    is      => 'ro',
+    default => undef,
 );
 
 =head2 set
@@ -119,7 +119,9 @@ sub set {
     $value = JSON::to_json($value);
 
     my $key = $category . '::' . $name;
-    $self->cache_writer->set($key => $value, $self->ttl ? ('EX' => $self->ttl) : ());
+    $self->cache_writer->set(
+        $key => $value,
+        $self->ttl ? ('EX' => $self->ttl) : ());
     $self->_archive($category, $name, $value, $rec_date) if $archive and $self->db_handle;
 
     return 1;
@@ -196,47 +198,6 @@ L<http://search.cpan.org/dist/Data-Chronicle/>
 
 =head1 ACKNOWLEDGEMENTS
 
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2016 Binary.com.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
-
-L<http://www.perlfoundation.org/artistic_license_2_0>
-
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
-
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
 =cut
 
 1;
